<!--
SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
SPDX-License-Identifier: GPL-3.0-or-later
-->

[![latest-docs](https://img.shields.io/badge/docs-v1.3.0-orange.svg)](https://mednet.readthedocs.io/en/v1.3.0/)
[![build](https://gitlab.idiap.ch/medai/software/mednet/badges/v1.3.0/pipeline.svg)](https://gitlab.idiap.ch/medai/software/mednet/commits/v1.3.0)
[![coverage](https://gitlab.idiap.ch/medai/software/mednet/badges/v1.3.0/coverage.svg)](https://www.idiap.ch/software/medai/docs/medai/software/mednet/v1.3.0/coverage/index.html)
[![repository](https://img.shields.io/badge/gitlab-project-0000c0.svg)](https://gitlab.idiap.ch/medai/software/mednet)

# Multi-task Library to Develop Computer-Aided Tools for Medical Data Analysis

Framework for development and analysis of deep neural network architectures
applied to medical data (images, 2D and 3D). This package can be readily used
on a number of public datasets.  It can be extended to add more datasets, and
models.

For installation and usage instructions, check-out our documentation.
